## Galen
The name of the project comes from  League of Legends.
Now galen is a common tool library 
## Installation

```shell
pip install galen
```
## Examples

### Cookie tools
```python
from galen.spider.cookies import format_cookies
cookies = 'aliyungf_tc=AQAAAOgxCHX0LwkAkKfqerDgQpnJBr44; csrfToken=LrCpyhAqhvA9d-R2PKLn84TG;'
print(format_cookies(cookies))
```
## Changelogs

| version      | release notes |
| :---      | :---    |
| 0.1.3    | add example |
| 0.1.2    | add markdown |
| 0.1.1    | project init cookie split function |
